rabbitmq.component.consumer


consumed-countclj

(consumed-count {:keys [consumed-count]})

Returns the number of consumed messages in test environment. Returns nil in production environment.

Returns the number of consumed messages in test environment.
Returns nil in production environment.
sourceraw docstring

Consumersclj

source

handler-fn->interceptorclj

(handler-fn->interceptor handler-fn)
source

wait-for-consumption!clj

(wait-for-consumption! consumer
                       expected-count
                       &
                       {:keys [timeout-ms] :or {timeout-ms 10000}})

Waits until the number of consumed messages reaches the expected count. Useful in integration tests to ensure all produced messages have been consumed before proceeding with assertions. Options: :timeout-ms - Maximum time to wait in milliseconds (default: 10000)

Waits until the number of consumed messages reaches the expected count.
Useful in integration tests to ensure all produced messages have been consumed
before proceeding with assertions.
Options:
  :timeout-ms - Maximum time to wait in milliseconds (default: 10000)
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries